"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArrayPayload = void 0;
const lodash_1 = __importDefault(require("lodash"));
const base_payload_1 = require("./base-payload");
const utils_1 = require("./utils");
class ArrayPayload extends base_payload_1.BasePayload {
    constructor() {
        super(...arguments);
        this.allowedPayloads = [];
    }
    getKind() {
        return 'array';
    }
    buildFromSchema(rawSchema) {
        if (!rawSchema['$_terms']?.items) {
            return this;
        }
        this.allowedPayloads = rawSchema['$_terms']?.items.map(rawSchema => (0, utils_1.generatePayload)(rawSchema));
        return this;
    }
    generateMock() {
        return this.allowedPayloads.map(allowedPayload => allowedPayload.generateMock());
    }
    generateAttacks() {
        const allAttacks = lodash_1.default.flatten(this.allowedPayloads.map(allowedPayload => allowedPayload.generateAttacks()));
        return allAttacks.map(attack => {
            return {
                ...attack,
                payload: [attack.payload]
            };
        });
    }
}
exports.ArrayPayload = ArrayPayload;
